@@ -4,9 +4,10 @@ xAgent - Multi-Modal AI Agent System
 A powerful multi-modal AI Agent system with modern architecture.
 """
 
-from .core import Session, Agent, HTTPAgentServer
-from .schemas import Message, ToolCall
-from .db import MessageDB
+from .core import Agent
+from .interfaces import HTTPAgentServer, CLIAgent
+from .schemas import Message
+from .components import MessageStorageBase, MessageStorageRedis, MessageStorageLocal
 from .utils import function_tool
 from .tools import web_search, draw_image
 from .multi import Swarm, Workflow
@@ -14,14 +15,19 @@ from .__version__ import __version__
 
 __all__ = [
     # Core components
-    "Session",
     "Agent", 
+
+    # interfaces
     "HTTPAgentServer",
+    "CLIAgent",
     
     # Data models
     "Message",
-    "ToolCall",
-    "MessageDB",
+
+    # Database
+    "MessageStorageBase",
+    "MessageStorageRedis",
+    "MessageStorageLocal",
     
     # Utilities
     "function_tool",
